==> ldapsaisie_1.2-1.tar.gz: ldapsaisie_clean/public_html/tmp/f42923f474b713ac9da912d26a6790568d7df7dd.ls.top.tpl.php <==
<?php /* Smarty version Smarty-3.1.21-dev, created on 2015-07-30 16:19:14
         compiled from "ls:top.tpl" */ ?>
<?php /*%%SmartyHeaderCode:192679165755ba4e82495594-02175282%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'f42923f474b713ac9da912d26a6790568d7df7dd' => 
    array (
      0 => 'ls:top.tpl',
      1 => 1372087220,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '192679165755ba4e82495594-02175282',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'LSencoding' => 0,
    'pagetitle' => 0,
    'LSsession_css' => 0,
    'LSsession_subDn' => 0,
    'label_level' => 0,
    '_refresh' => 0,
    'LSsession_subDn_indexes' => 0,
    'LSsession_subDn_names' => 0,
    'LSaccess' => 0,
    'LSobject_type' => 0,
    'label' => 0,
    'lang_label' => 0,
    'LSlang' => 0,
    'LSlanguages' => 0,
    'lang' => 0,
    'displaySelfAccess' => 0,
    'connected_as' => 0,
    'LSsession_username' => 0,
    'displayLogoutBtn' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_55ba4e824cee99_73582324',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_55ba4e824cee99_73582324')) {function content_55ba4e824cee99_73582324($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
?><?php echo '<?xml';?> version="1.0"<?php echo '?>';?>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=<?php echo $_smarty_tpl->tpl_vars['LSencoding']->value;?>
">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value!='') {?> - <?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base.css'),$_smarty_tpl);?>
" title="Normal" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base_print.css'),$_smarty_tpl);?>
" media='print' title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

  </head>
<body>

<?php echo $_smarty_tpl->getSubTemplate ('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>


<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <a href='index.php'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='logo'/></a>
      
      <?php if ($_smarty_tpl->tpl_vars['LSsession_subDn']->value!='') {?>
        <form action="index.php" method='post' id='LSsession_topDn_form'>
          <label><?php echo $_smarty_tpl->tpl_vars['label_level']->value;?>

            <a href="index.php?LSsession_refresh"><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['_refresh']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['_refresh']->value;?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>
      <ul class='menu'>
      <?php  $_smarty_tpl->tpl_vars['label'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['label']->_loop = false;
 $_smarty_tpl->tpl_vars['LSobject_type'] = new Smarty_Variable;
 $_from = $_smarty_tpl->tpl_vars['LSaccess']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['label']->key => $_smarty_tpl->tpl_vars['label']->value) {
$_smarty_tpl->tpl_vars['label']->_loop = true;
 $_smarty_tpl->tpl_vars['LSobject_type']->value = $_smarty_tpl->tpl_vars['label']->key;
?>
        <li class='menu'><a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSobject_type']->value;?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
</a></li>
      <?php } ?>
      </ul>
    </td>
    <td id='status'>
    <span><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php  $_smarty_tpl->tpl_vars['lang'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['lang']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSlanguages']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->key => $_smarty_tpl->tpl_vars['lang']->value) {
$_smarty_tpl->tpl_vars['lang']->_loop = true;
?>
        <option value='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'><?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
</option>
      <?php } ?>
      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo $_smarty_tpl->tpl_vars['connected_as']->value;?>
 <span id='user_name'><?php echo $_smarty_tpl->tpl_vars['LSsession_username']->value;?>
</span><?php }
if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
' alt='Logout' title='Logout' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>
    
    

    
<?php }} ?>

==> ldapsaisie_1.4-1.tar.gz: ldapsaisie_clean/public_html/tmp/f42923f474b713ac9da912d26a6790568d7df7dd.ls.top.tpl.php <==
<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:22:37
         compiled from "ls:top.tpl" */ ?>
<?php /*%%SmartyHeaderCode:1311245299585171cdc10155-69753689%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'f42923f474b713ac9da912d26a6790568d7df7dd' => 
    array (
      0 => 'ls:top.tpl',
      1 => 1472212678,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '1311245299585171cdc10155-69753689',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'LSencoding' => 0,
    'pagetitle' => 0,
    'LSsession_css' => 0,
    'LSsession_subDn' => 0,
    'label_level' => 0,
    '_refresh' => 0,
    'LSsession_subDn_indexes' => 0,
    'LSsession_subDn_names' => 0,
    'LSaccess' => 0,
    'LSobject_type' => 0,
    'label' => 0,
    'LSaddonsViewsAccess' => 0,
    'access' => 0,
    'lang_label' => 0,
    'LSlang' => 0,
    'LSlanguages' => 0,
    'lang' => 0,
    'displaySelfAccess' => 0,
    'connected_as' => 0,
    'LSsession_username' => 0,
    'displayLogoutBtn' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_585171cdc35205_62573608',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_585171cdc35205_62573608')) {function content_585171cdc35205_62573608($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=<?php echo $_smarty_tpl->tpl_vars['LSencoding']->value;?>
">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value!='') {?> - <?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base.css'),$_smarty_tpl);?>
" title="Normal" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'base_print.css'),$_smarty_tpl);?>
" media='print' title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

  </head>
<body>

<?php echo $_smarty_tpl->getSubTemplate ('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>


<table id='main'>
  <tr>
    <td rowspan=2 id='left'>
      <a href='index.php'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='logo'/></a>
      
      <?php if ($_smarty_tpl->tpl_vars['LSsession_subDn']->value!='') {?>
        <form action="index.php" method='post' id='LSsession_topDn_form'>
          <label><?php echo $_smarty_tpl->tpl_vars['label_level']->value;?>

            <a href="index.php?LSsession_refresh"><img src='<?php echo LStemplate_smarty_img(array('name'=>'refresh'),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['_refresh']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['_refresh']->value;?>
' /></a>
            <select name='LSsession_topDn' id='LSsession_topDn'>
              <?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['LSsession_subDn_indexes']->value,'output'=>$_smarty_tpl->tpl_vars['LSsession_subDn_names']->value,'selected'=>$_smarty_tpl->tpl_vars['LSsession_subDn']->value),$_smarty_tpl);?>

            </select>
          </label>
        </form>
      <?php }?>
      <ul class='menu'>
      <?php  $_smarty_tpl->tpl_vars['label'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['label']->_loop = false;
 $_smarty_tpl->tpl_vars['LSobject_type'] = new Smarty_Variable;
 $_from = $_smarty_tpl->tpl_vars['LSaccess']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['label']->key => $_smarty_tpl->tpl_vars['label']->value) {
$_smarty_tpl->tpl_vars['label']->_loop = true;
 $_smarty_tpl->tpl_vars['LSobject_type']->value = $_smarty_tpl->tpl_vars['label']->key;
?>
        <li class='menu'><a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSobject_type']->value;?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
</a></li>
      <?php } ?>
      <?php  $_smarty_tpl->tpl_vars['access'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['access']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSaddonsViewsAccess']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['access']->key => $_smarty_tpl->tpl_vars['access']->value) {
$_smarty_tpl->tpl_vars['access']->_loop = true;
?>
        <?php if ($_smarty_tpl->tpl_vars['access']->value['showInMenu']) {?>
        <li class='menu'><a href='addon_view.php?LSaddon=<?php echo $_smarty_tpl->tpl_vars['access']->value['LSaddon'];?>
&view=<?php echo $_smarty_tpl->tpl_vars['access']->value['id'];?>
' class='menu'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['access']->value['label']),$_smarty_tpl);?>
</a></li>
        <?php }?>
      <?php } ?>
      </ul>
    </td>
    <td id='status'>
    <span><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
'/></span>
    <form action='' methode='post' style='display: none' class='LSlang_hidden'>
      <select name='lang'>
      <?php  $_smarty_tpl->tpl_vars['lang'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['lang']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSlanguages']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->key => $_smarty_tpl->tpl_vars['lang']->value) {
$_smarty_tpl->tpl_vars['lang']->_loop = true;
?>
        <option value='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'><?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
</option>
      <?php } ?>
      </select>
      <input type='submit' value='->'/>
    </form>
    <?php if ($_smarty_tpl->tpl_vars['displaySelfAccess']->value) {
echo $_smarty_tpl->tpl_vars['connected_as']->value;?>
 <span id='user_name'><?php echo $_smarty_tpl->tpl_vars['LSsession_username']->value;?>
</span><?php }
if ($_smarty_tpl->tpl_vars['displayLogoutBtn']->value) {?> <a href='index.php?LSsession_logout'><img src='<?php echo LStemplate_smarty_img(array('name'=>'logout'),$_smarty_tpl);?>
' alt='Logout' title='Logout' /></a><?php }?>
    </td>
  </tr>
  <tr>
    <td id='right'>
    
    

    
<?php }} ?>
